@@ -3,7 +3,7 @@ from tensorflow.keras.models import Model
 from tensorflow.keras.callbacks import ModelCheckpoint
 from tensorflow.keras.callbacks import EarlyStopping
 from tensorflow.keras.preprocessing.sequence import pad_sequences
-from eng_syl.BahdanauAttention import AttentionLayer
+from .BahdanauAttention import AttentionLayer
 import numpy as np
 import pickle
 import os
@@ -13,8 +13,6 @@ class wordSegmenter:
         self.this_dir, this_filename = os.path.split(__file__)
         path_e2i = os.path.join(self.this_dir, "e2i_w2s.pkl")
         path_d2i = os.path.join(self.this_dir, "d2i_w2s.pkl")
-        path_e2i = path_e2i.replace("\\", "/")
-        path_d2i = path_d2i.replace("\\", "/")
 
         e2i_file = open(path_e2i, 'rb')
         d2i_file = open(path_d2i, 'rb')
@@ -85,7 +83,6 @@ class wordSegmenter:
 
     def load_model_weights(self, filename = "Segmenter2.0_bestweights.h5"):
         weight_path = os.path.join(self.this_dir, filename)
-        weight_path = weight_path.replace("\\", "/")
         self.training_model.load_weights(weight_path)
 
     def build_inference_model(self):
